French ECQ La Guilde des Jeux, Paris, France September 20th 2003 38 players Jo Herroelen 38 players attended the event: we enjoyed the presence of German, Belgian and Spanish players. "Fast Eddie" Crypt (14 cards, min=8, max=26, avg=4.64) ----------------------------------------- 2x General Perfidio Díos 5 AUS dem obf bishop Malkavian antitribu:3 1x Korah 7 AUS DEM OBF ani priscus Malkavian antitribu:2 1x Quentin King III (ADV) 7 AUS DEM OBF cel pre Malkavian:3 1x Dolphin Black 6 AUS DEM OBF Malkavian antitribu:2 1x Dr. Douglas Netchurch 6 AUS OBF dem dom Malkavian:3 1x Tony 6 AUS DEM dom obf Malkavian:3 1x Evan Klein 5 OBF aus dem pre Malkavian:3 1x Persia, The Beautiful Statue 5 DEM aus obf Malkavian:3 1x Uncle George 5 DEM aus dom obf Malkavian antitribu:3 1x Yorik 3 dem obf Malkavian antitribu:2 1x Boy Toy 2 dem Malkavian antitribu:2 1x Gillian Krader 2 ani dem Pander:2 1x Eddie Gaines 1 dem pot Caitiff:3 Library (90 cards) Master (20) 1x Archon Investigation 2x Blood Doll 3x Dementation 3x Direct Intervention 5x Dreams of the Sphinx 1x Obfuscate 1x Pentex(TM) Subversion 2x Secure Haven 2x Sudden Reversal Action (19) 17x Kindred Spirits 2x Restructure Action Modifier (30) 3x Cloak the Gathering 5x Confusion 2x Domain of Evernight 3x Elder Impersonation 8x Eyes of Chaos 3x Faceless Night 3x Lost in Crowds 3x Spying Mission Action Modifier/Combat (5) 3x Deny 2x Swallowed by the Night Reaction (16) 3x Delaying Tactics 2x My Enemy's Enemy 7x Telepathic Misdirection 4x Wake with Evening's Freshness